/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -\
| Date:      			    05/15/2005  	   	      	|
| Revised: 					              			|
| Title:  		   		Bosnia LSMS Panel		      	|
| File-name: 	     		cr1.2_dataset.do		   	      |
| Purpose: 	  		     Creating LSMS Panel		      |
| Author:  	 Georgios A. Panos                       			|
| Contact:   gpanos@worldbank.org			   	      	|
|          	 gpanos@uom.gr          		   	   	      |
\ - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -*/ 

/* - - - - - - - - - - - - - - - - - - options - - - - - - - - - - - - - - - - - - - - - */
#delimit ; 
clear; 
set more off; 
set memory 100m; 
capture log close; 
* set trace on; 
/* - - - - - - - - - - - - - - - - - - - - - - - - paths - - - - - - - - - - - - - - - - - - - - - - - -*/;
local path1 C:\Bosnia_Project\DATA; 
local path2 C:\Bosnia_Project\Log-files;  
local path3 C:\Bosnia_Project\DATA\Original;  
/* - - - - - - - - - - - - - - - - - - - - - - - tempfiles - - - - - - - - - - - - - - - - - - - - - -*/;
tempfile tmp1; tempfile tmp2; tempfile tmp3; tempfile tmp4; tempfile tmp5; tempfile tmp6; 
/* - - - CONSUMPTION & POVERTY LINE FILES FOR 2001 & 2004 - - - */;
cd "`path3'"; 
use BiH2001_3.dta, clear; rename hid plhid; sort muncode gnd numist plhid; save `tmp5', replace; 
use BiH2004_3.dta, clear; rename hhid hid; sort hid; save `tmp6', replace; 
/* - - - - - - - - - Household identifiers for 2002 and 2003 - - - - - - - - - - */;
/* - - - - - - - - - - BHIHH - FILES: Household Level - - - - - - - - - - - - - -*/;
cd "`path2'"; log using cr_dataset.log, append; 
cd "`path3'"; 
use sub_abhihh.dta, clear; rename hid plhid;    
rename acaseid hid; lab var hid "Household Identifier (IDD) LiBiH"; rename a2_01 d_type; lab var d_type "Main construction type of dwelling";
rename a2_02 d_complete; lab var d_complete "Completness of dwelling unit"; rename a2_03 d_age; lab var d_age "Year of construction";
rename a2_04 d_area; lab var d_area "Area of dwelling"; rename a2_05 d_rooms; lab var d_rooms "Rooms used by HH";
rename a2_06a d_kitchen; lab var d_kitchen "Dwelling has separate kitchen"; rename a2_06b d_wc; lab var d_wc "Dwelling has bathroom with WC";
rename a2_06c d_bath; lab var d_bath "Dwelling has WC with separate bathroom"; rename a2_06d d_corr; lab var d_corr "Dwelling has Corridor";
rename a2_06e d_pantry; lab var d_pantry "Dwelling has Pantry"; rename a2_06f d_balcony; lab var d_balcony "Dwelling has Balcony or terrace";
rename a2_06g d_cellar; lab var d_cellar "Dwelling has Cellar"; rename a2_06h d_attic; lab var d_attic "Dwelling has Attic";
rename a2_06i d_woodshed; lab var d_woodshed "Dwelling has Woodshed"; rename a2_06j d_garage; lab var d_garage "Dwelling has Garage";
rename a2_11 d_en_hours; lab var d_en_hours "Hour electricity was available in last month"; rename a2_12 d_water; lab var d_water "Source of drinking water";
rename a2_13 d_wtr_dist; lab var d_wtr_dist "Meters source away"; rename a2_14 d_wtr_hrs; lab var d_wtr_hrs "Hours a day dwelling received water last month";
rename a2_15 d_heating; lab var d_heating	"Main source of heating for dwelling"; rename a2_16 d_energy; lab var d_energy "Main type of energy";
rename a2_19 d_sewer; lab var	d_sewer "Dwelling connected to sewer"; rename a2_21 d_phone; lab var d_phone "HH has access to telephone";
rename a2_35 d_sell; lab var d_sell	"Can sell dwelling"; rename a2_36 d_rent; lab var d_rent "Amount of rent";
rename a2_37 d_owner; lab var	d_owner "Owner of dwelling"; rename a2_38 d_rent_amt; lab var d_rent_amt "Monthly rent of dwelling";
rename a2_39a d_common_amt; lab var d_common_amt "Amount spent on common room fees"; rename a2_39b d_electr_amt; lab var d_electr_amt "Amount spent on electricity";
rename a2_39c d_gas_amt; lab var d_gas_amt "Amount spent on piped gas"; rename a2_39d d_hotwtr_amt; lab var d_hotwtr_amt "Amount spent on hot water";
rename a2_39e d_bl_heat; lab var d_bl_heat "district heat"; rename a2_39f d_bl_waste; lab var d_bl_waste "solid waste disposal";
rename a2_39g d_bl_phone; lab var d_bl_phone "telephone"; rename a2_39h d_bl_tvr; lab var d_bl_tvr "TV and radio subscriptions";
rename a2_39i d_bl_insur; lab var d_bl_insur "House or flat insurance"; rename a2_39j d_bl_land; lab var d_bl_land "Land occupation fee";
rename a2_40a1 d_bl_gaslm; lab var d_bl_gaslm "Amount spent by HH in gas LM"; rename a2_40a2 d_bl_gaswm; lab var d_bl_gaswm "Amount spent by HH in gas WM";
rename a2_40b1 d_bl_oillm; lab var d_bl_oillm "Amount spent by HH in oil LM"; rename a2_40b2 d_bl_oilwm; lab var d_bl_oilwm "Amount spent by HH in oil WM";
rename a2_40c1 d_bl_coallm; lab var d_bl_coallm "Amount spent by HH in coal LM"; rename a2_40c2 d_bl_coalwm; lab var d_bl_coalwm "Amount spent by HH in coal WM";
rename a2_40d1 d_bl_woodlm; lab var d_bl_woodlm "Amount spent by HH Firewood LM"; rename a2_40d2 d_bl_woodwm; lab var d_bl_woodwm "Amount spent by HH Firewood WM";
rename a2_40e1 d_bl_wtrlm; lab var d_bl_wtrlm "Amount spent by HH in water LM"; rename a2_40e2 d_bl_wtrwm; lab var d_bl_wtrwm "Amount spent by HH in water WM";
rename a2_40f d_bl_elwm; lab var d_bl_elwm "Amount spent by HH on electricity WM"; rename a2_40g d_bl_pipewm; lab var d_bl_pipewm "Amount spent by HH on piped gas WM";
rename a2_41 d_hastwo; lab var d_hastwo "Other HH member own another building or house"; rename a2_42 d_use; lab var d_use "Usage of dwelling";
rename a2_43 d_price; lab var d_price "Dwelling price"; rename a2_22 houseown; rename a2_33 document; 	
keep hid d_type d_complete d_age d_area d_rooms d_kitchen d_wc d_bath d_corr d_pantry d_balcony d_cellar
	d_attic d_woodshed d_garage d_en_hours d_water d_wtr_dist d_wtr_hrs d_heating d_energy d_sewer d_phone 
	d_sell d_rent d_owner d_rent_amt d_common_amt d_electr_amt d_gas_amt d_hotwtr_amt d_bl_heat d_bl_waste 
	d_bl_phone d_bl_tvr d_bl_insur d_bl_land d_bl_gaslm d_bl_gaswm d_bl_oillm d_bl_oilwm d_bl_coallm 
	d_bl_coalwm d_bl_woodlm d_bl_woodwm d_bl_wtrlm d_bl_wtrwm d_bl_elwm d_bl_pipewm d_hastwo d_use d_price entity gnd numist muncode plhid houseown document; 
sort muncode gnd numist plhid; merge muncode gnd numist plhid using `tmp5'; tab _merge; keep if _merge==3; drop _merge; 
drop year; gen wave=1; gen year=2001; sort hid; assert hid!=hid[_n+1]; 
save `tmp1', replace; clear; 

use bbhihh.dta, clear;    
gen hid=acaseid; replace hid=bcaseid if missing(hid);  
rename b2_01 d_new; lab var d_new "New dwelling check"; rename b2_02 d_type; lab var d_type "Main construction type of dwelling";
rename b2_03 d_complete; lab var d_complete "Completness of dwelling unit"; rename b2_04 d_age; lab var d_age "Year of construction";
rename b2_05 d_area; lab var d_area "Area of dwelling"; rename b2_06 d_rooms; lab var d_rooms "Rooms used by HH";
rename b2_07a d_kitchen; lab var d_kitchen "Dwelling has separate kitchen"; rename b2_07b d_wc; lab var d_wc "Dwelling has bathroom with WC";
rename b2_07c d_bath; lab var d_bath "Dwelling has WC with separate bathroom"; rename b2_07d d_corr; lab var d_corr "Dwelling has Corridor";
rename b2_07e d_pantry; lab var d_pantry "Dwelling has Pantry"; rename b2_07f d_balcony; lab var d_balcony "Dwelling has Balcony or terrace";
rename b2_07g d_cellar; lab var d_cellar "Dwelling has Cellar"; rename b2_07h d_attic; lab var d_attic "Dwelling has Attic";
rename b2_07i d_woodshed; lab var d_woodshed "Dwelling has Woodshed"; rename b2_07j d_garage; lab var d_garage "Dwelling has Garage";
rename b2_27 d_en_hours; lab var d_en_hours "Hour electricity was available in last month"; rename b2_08 d_water; lab var d_water "Source of drinking water";
rename b2_09 d_wtr_dist; lab var d_wtr_dist "Meters source away"; rename b2_28 d_wtr_hrs; lab var d_wtr_hrs "Hours a day dwelling received water last month";
rename b2_10 d_heating; lab var d_heating "Main source of heating for dwelling"; rename b2_11 d_energy; lab var d_energy"Main type of energy";
rename b2_12 d_sewer; lab var d_sewer "Dwelling connected to sewer"; rename b2_13 d_phone; lab var d_phone "HH has access to telephone";
rename b2_23 d_sell; lab var d_sell "Can sell dwelling"; rename b2_24 d_rent; lab var d_rent "Amount of rent";
rename b2_25 d_owner; lab var	d_owner "Owner of dwelling"; rename b2_26 d_rent_amt; lab var d_rent_amt "Monthly rent of dwelling";
rename b2_31a d_common_amt; lab var d_common_amt "Amount spent on common room fees"; rename b2_29f d_electr_amt; lab var d_electr_amt "Amount spent on electricity";
rename b2_29g d_gas_amt; lab var d_gas_amt "Amount spent on piped gas"; rename b2_31b d_hotwtr_amt; lab var d_hotwtr_amt "Amount spent on hot water";
rename b2_31c d_bl_heat; lab var d_bl_heat "district heat"; rename b2_31d d_bl_waste; lab var d_bl_waste "solid waste disposal";
rename b2_31e d_bl_phone; lab var d_bl_phone "telephone"; rename b2_31f d_bl_cell; lab var d_bl_cell "Mobile phone";
rename b2_31g d_bl_net; lab var d_bl_net "internet"; rename b2_31h d_bl_tvr; lab var d_bl_tvr "TV and radio subscriptions";
rename b2_31i d_bl_insur; lab var d_bl_insur "House or flat insurance"; rename b2_31j d_bl_land; lab var d_bl_land "Land occupation fee";
rename b2_29a d_bl_gaslm; lab var d_bl_gaslm "Amount spent by HH in gas LM"; rename b2_30a d_bl_gaswm; lab var d_bl_gaswm "Amount spent by HH in gas WM";
rename b2_29b d_bl_oillm; lab var d_bl_oillm "Amount spent by HH in oil LM"; rename b2_30b d_bl_oilwm; lab var d_bl_oilwm "Amount spent by HH in oil WM";
rename b2_29c d_bl_coallm; lab var d_bl_coallm "Amount spent by HH in coal LM"; rename b2_30c d_bl_coalwm; lab var d_bl_coalwm "Amount spent by HH in coal WM";
rename b2_29d d_bl_woodlm; lab var d_bl_woodlm "Amount spent by HH Firewood LM"; rename b2_30d d_bl_woodwm; lab var d_bl_woodwm "Amount spent by HH Firewood WM";
rename b2_29e d_bl_wtrlm; lab var d_bl_wtrlm "Amount spent by HH in water LM"; rename b2_30e d_bl_wtrwm; lab var d_bl_wtrwm "Amount spent by HH in water WM";
rename b2_30f d_bl_elwm; lab var d_bl_elwm "Amount spent by HH on electricity WM"; rename b2_30g d_bl_pipewm; lab var d_bl_pipewm "Amount spent by HH on piped gas WM";
rename b2_32 d_hastwo; lab var d_hastwo "Other HH member own another building or house"; rename b2_33 d_use; lab var d_use "Usage of dwelling";
rename b2_34 d_price; lab var d_price "Dwelling price"; rename b2_35a buy_social; lab var buy_social "Can you afford friends,family meal";
rename b2_35b buy_holiday; lab var buy_holiday "Can you afford annual holiday"; rename b2_35c buy_furnit; lab var buy_furnit "Can you afford replace furniture";
rename b2_35d buy_cloth; lab var buy_cloth "Can you afford new clothes"; rename b2_35e buy_meat; lab var buy_meat "Can you afford meat";
rename b2_35f buy_heat; lab var buy_heat "Can you afford warm house"; rename b2_36 buy_rent; lab var buy_rent "Difficulties in 12 months paying house";
rename b2_37 d_borrowed; lab var d_borrowed "Borrowed money for house"; rename b2_38 d_cutexp; lab var d_cutexp "Cut back on spending for house";
rename b2_39a d_p_space; lab var d_p_space "Shortage of space"; rename b2_39b d_p_neigh; lab var d_p_neigh "Noise from neighbours";
rename b2_39c d_p_noise; lab var d_p_noise "Street noise"; rename b2_39d d_p_dark; lab var d_p_dark "Too dark";
rename b2_39e d_p_noheat; lab var d_p_noheat "Lack of heating"; rename b2_39f d_p_war; lab var d_p_war "War damage";
rename b2_39g d_p_roof; lab var d_p_roof "Leaky room"; rename b2_39h d_p_damp; lab var d_p_damp "Damp";
rename b2_39i d_p_rot; lab var d_p_rot "Rot"; rename b2_39j d_p_poltn; lab var d_p_poltn "Pollution"; rename b2_39k d_p_vandal; lab var d_p_vandal "Vandalism";
rename b2_40 car_own; lab var car_own "Has car"; rename b2_41 cost_trnsp; lab var cost_trnsp "Transport costs"; rename b2_16 houseown; rename b2_21 document; 	
keep hid d_new d_type d_complete d_age d_area d_rooms
	d_kitchen d_wc d_bath d_corr d_pantry d_balcony d_cellar d_attic d_woodshed d_garage d_en_hours d_water d_wtr_dist
	d_wtr_hrs d_heating d_energy d_sewer d_phone d_sell d_rent d_owner d_rent_amt d_common_amt d_electr_amt d_gas_amt 
	d_hotwtr_amt d_bl_heat d_bl_waste d_bl_phone d_bl_cell d_bl_net d_bl_tvr d_bl_insur d_bl_land d_bl_gaslm d_bl_gaswm
	d_bl_oillm d_bl_oilwm d_bl_coallm d_bl_coalwm d_bl_woodlm d_bl_woodwm d_bl_wtrlm d_bl_wtrwm d_bl_elwm d_bl_pipewm d_hastwo 
	d_use d_price buy_social buy_holiday buy_furnit buy_cloth buy_meat buy_heat buy_rent d_borrowed d_cutexp d_p_space 
	d_p_neigh d_p_noise d_p_dark d_p_noheat d_p_war d_p_roof d_p_damp d_p_rot d_p_poltn d_p_vandal car_own cost_trnsp bcaseid houseown document; 
gen wave=2; gen year=2002; sort hid; save `tmp2', replace; clear; 

use cbhihh.dta, clear;  
rename ccaseid hid; rename c2_q01 d_new; rename c2_q02 d_type; rename c2_q03 d_complete; rename c2_q04 d_age;
rename c2_q05 d_area; rename c2_q06 d_rooms; rename c2_q7a d_kitchen; rename c2_q7b d_wc; rename c2_q7c d_bath; rename c2_q7d d_corr;
rename c2_q7e d_pantry; rename c2_q7f d_balcony; rename c2_q7g d_cellar; rename c2_q7h d_attic; rename c2_q7i d_woodshed; rename c2_q7j d_garage;
rename c2_q27 d_en_hours; rename c2_q08 d_water; rename c2_q09 d_wtr_dist; rename c2_q28 d_wtr_hrs; rename c2_q10 d_heating;
rename c2_q11 d_energy; rename c2_q12 d_sewer; rename c2_q13 d_phone; rename c2_q23 d_sell; rename c2_q24 d_rent; rename c2_q25 d_owner;
rename c2_q26 d_rent_amt; rename c2_q31a d_common_amt; rename c2_q29f d_electr_amt; rename c2_q29g d_gas_amt; rename c2_q31b d_hotwtr_amt;
rename c2_q31c d_bl_heat; rename c2_q31d d_bl_waste; rename c2_q31e d_bl_phone; rename c2_q31f d_bl_cell; rename c2_q31g d_bl_net;
rename c2_q31h d_bl_tvr; rename c2_q31i d_bl_insur; rename c2_q31j d_bl_land; rename c2_q29a d_bl_gaslm; rename c2_q30a d_bl_gaswm;
rename c2_q29b d_bl_oillm; rename c2_q30b d_bl_oilwm; rename c2_q29c d_bl_coallm; rename c2_q30c d_bl_coalwm; rename c2_q29d d_bl_woodlm; 
rename c2_q30d d_bl_woodwm; rename c2_q29e d_bl_wtrlm; rename c2_q30e d_bl_wtrwm; rename c2_q30f d_bl_elwm; rename c2_q30g d_bl_pipewm;
rename c2_q32 d_hastwo; rename c2_q33 d_use; rename c2_q34 d_price; rename c2_q35a buy_social; rename c2_q35b buy_holiday; rename c2_q35c buy_furnit; 
rename c2_q35d buy_cloth; rename c2_q35e buy_meat; rename c2_q35f buy_heat; rename c2_q36 buy_rent; rename c2_q37 d_borrowed; rename c2_q38 d_cutexp; 
rename c2_q39a d_p_space; rename c2_q39b d_p_neigh; rename c2_q39c d_p_noise; rename c2_q39d d_p_dark; rename c2_q39e d_p_noheat; rename c2_q39f d_p_war; 
rename c2_q39g d_p_roof; rename c2_q39h d_p_damp; rename c2_q39i d_p_rot; rename c2_q39j d_p_poltn; rename c2_q39k d_p_vandal; rename c2_q40 car_own; 
rename c2_q41 cost_trnsp; rename c2_q16 houseown; rename c2_q21 document; 	
keep hid d_new d_type d_complete d_age d_area d_rooms d_kitchen d_wc d_bath d_corr d_pantry d_balcony d_cellar d_attic
	d_woodshed d_garage d_en_hours d_water d_wtr_dist d_wtr_hrs d_heating d_energy d_sewer d_phone d_sell d_rent d_owner d_rent_amt
	d_common_amt d_electr_amt d_gas_amt d_hotwtr_amt d_bl_heat d_bl_waste d_bl_phone d_bl_cell d_bl_net d_bl_tvr d_bl_insur d_bl_land
	d_bl_gaslm d_bl_gaswm d_bl_oillm d_bl_oilwm d_bl_coallm d_bl_coalwm d_bl_woodlm d_bl_woodwm d_bl_wtrlm d_bl_wtrwm d_bl_elwm
	d_bl_pipewm d_hastwo d_use d_price buy_social buy_holiday buy_furnit buy_cloth buy_meat buy_heat buy_rent d_borrowed d_cutexp
	d_p_space d_p_neigh d_p_noise d_p_dark d_p_noheat d_p_war d_p_roof d_p_damp d_p_rot d_p_poltn d_p_vandal car_own cost_trnsp houseown document;
gen wave=3; gen year=2003; sort hid; assert hid!=hid[_n+1]; save `tmp3', replace; clear; 

use dbhihh_bih.dta, clear;  
rename case_id overhid; rename d2_q01 d_new; rename d2_q02 d_type; rename d2_q03 d_complete;rename d2_q04 d_age;
rename d2_q05 d_area; rename d2_q06 d_rooms; rename d2_q7a d_kitchen; rename d2_q7b d_wc; rename d2_q7c d_bath; rename d2_q7d d_corr; rename d2_q7e d_pantry;
rename d2_q7f d_balcony; rename d2_q7g d_cellar; rename d2_q7h d_attic; rename d2_q7i d_woodshed; rename d2_q7j d_garage;
rename d2_q27 d_en_hours; rename d2_q08 d_water; rename d2_q09 d_wtr_dist; rename d2_q28 d_wtr_hrs; rename d2_q10 d_heating;
rename d2_q11 d_energy; rename d2_q12b d_sewer; rename d2_q13 d_phone; rename d2_q23 d_sell; rename d2_q24 d_rent; rename d2_q25 d_owner;
rename d2_q26 d_rent_amt; rename d2_q31a d_common_amt; rename d2_q29f d_electr_amt; rename d2_q29g d_gas_amt; rename d2_q31b d_hotwtr_amt;
rename d2_q31c d_bl_heat; rename d2_q31d d_bl_waste; rename d2_q31e d_bl_phone; rename d2_q31f d_bl_cell; rename d2_q31g d_bl_net;
rename d2_q31h d_bl_tvr; rename d2_q31i d_bl_insur; rename d2_q31j d_bl_land; rename d2_q29a d_bl_gaslm; rename d2_q30a d_bl_gaswm;
rename d2_q29b d_bl_oillm;rename d2_q30b d_bl_oilwm; rename d2_q29c d_bl_coallm; rename d2_q30c d_bl_coalwm; rename d2_q29d d_bl_woodlm;
rename d2_q30d d_bl_woodwm;rename d2_q29e d_bl_wtrlm; rename d2_q30e d_bl_wtrwm; rename d2_q30f d_bl_elwm; rename d2_q30g d_bl_pipewm;
rename d2_q32 d_hastwo; rename d2_q33 d_use; rename d2_q34 d_price;rename d2_q35a buy_social; rename d2_q35b buy_holiday; rename d2_q35c buy_furnit; 
rename d2_q35d buy_cloth; rename d2_q35e buy_meat; rename d2_q35f buy_heat; rename d2_q36 buy_rent; rename d2_q37 d_borrowed; rename d2_q38 d_cutexp; 
rename d2_q39a d_p_space; rename d2_q39b d_p_neigh; rename d2_q39c d_p_noise; rename d2_q39d d_p_dark; rename d2_q39e d_p_noheat; rename d2_q39f d_p_war; 
rename d2_q39g d_p_roof; rename d2_q39h d_p_damp; rename d2_q39i d_p_rot; rename d2_q39j d_p_poltn; rename d2_q39k d_p_vandal; rename d2_q40 car_own; 
rename d2_q41 cost_trnsp; rename d2_q16 houseown; rename d2_q21 document; 
keep hid d_new d_type d_complete d_age d_area d_rooms d_kitchen d_wc d_bath d_corr d_pantry d_balcony d_cellar d_attic
	d_woodshed d_garage d_en_hours d_water d_wtr_dist d_wtr_hrs d_heating d_energy d_sewer d_phone d_sell d_rent d_owner d_rent_amt
	d_common_amt d_electr_amt d_gas_amt d_hotwtr_amt d_bl_heat d_bl_waste d_bl_phone d_bl_cell d_bl_net d_bl_tvr d_bl_insur d_bl_land
	d_bl_gaslm d_bl_gaswm d_bl_oillm d_bl_oilwm d_bl_coallm d_bl_coalwm d_bl_woodlm d_bl_woodwm d_bl_wtrlm d_bl_wtrwm d_bl_elwm
	d_bl_pipewm d_hastwo d_use d_price buy_social buy_holiday buy_furnit buy_cloth buy_meat buy_heat buy_rent d_borrowed d_cutexp
	d_p_space d_p_neigh d_p_noise d_p_dark d_p_noheat d_p_war d_p_roof d_p_damp d_p_rot d_p_poltn d_p_vandal car_own cost_trnsp overhid houseown document;
sort hid; merge hid using `tmp6'; tab _merge; keep if _merge==3; drop _merge; 
drop year; gen wave=4; gen year=2004; sort hid; assert hid!=hid[_n+1]; save `tmp4', replace; clear; 


use `tmp1', clear; 
append using `tmp2'; 
append using `tmp3'; 
append using `tmp4';
drop if missing(hid); 
egen hid2=group(hid); 
sort hid2 wave; iis hid2; tis year; xtdes; 
save file2, replace; 

capture log close; clear; 

